[newlib-cygwin] fhandler_serial: fix comments

Corinna Vinschen corinna@sourceware.org
Thu Mar 26 11:27:01 GMT 2020


https://sourceware.org/git/gitweb.cgi?p=newlib-cygwin.git;h=8ffe12b394e4ed593b38c991da6d094100c3b78d

commit 8ffe12b394e4ed593b38c991da6d094100c3b78d
Author: Corinna Vinschen <corinna@vinschen.de>
Date:   Wed Mar 25 12:25:06 2020 +0100

    fhandler_serial: fix comments
    
    Signed-off-by: Corinna Vinschen <corinna@vinschen.de>

Diff:
---
 winsup/cygwin/fhandler_serial.cc | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/winsup/cygwin/fhandler_serial.cc b/winsup/cygwin/fhandler_serial.cc
index 1750a9f97..3fd8a974c 100644
--- a/winsup/cygwin/fhandler_serial.cc
+++ b/winsup/cygwin/fhandler_serial.cc
@@ -45,7 +45,7 @@ fhandler_serial::raw_read (void *ptr, size_t& ulen)
   if (ulen == 0)
     return;
 
   /* If VMIN > 0 in blocking mode, we have to wait for at least VMIN chars.
      Otherwise we're in polling mode and there's no minimum chars. */
   ssize_t minchars = is_nonblocking () ? 0 : vmin_;
 
@@ -85,8 +85,8 @@ fhandler_serial::raw_read (void *ptr, size_t& ulen)
 	     and don't wait. */
 	  if (st.cbInQue && st.cbInQue >= minchars)
 	    bytes_to_read = MIN (st.cbInQue, bytes_to_read);
-	  /* Otherwise, if VMIN > 0, VTIME == 0, we have to wait until
-	     VMIN bytes are available in the inbound queue. */
+	  /* Otherwise, if MIN > 0, TIME == 0, we have to wait until
+	     MIN bytes are available in the inbound queue. */
 	  else if (minchars && !vtime_)
 	    wait_for_vmin = true;
 	}
@@ -45,7 +45,7 @@ fhandler_serial::raw_read (void *ptr, size_t& ulen)
     return;
 
-  /* If VMIN > 0 in blocking mode, we have to wait for at least VMIN chars.
+  /* If MIN > 0 in blocking mode, we have to wait for at least MIN chars.
      Otherwise we're in polling mode and there's no minimum chars. */
   ssize_t minchars = is_nonblocking () ? 0 : vmin_;


More information about the Cygwin-cvs mailing list